@@ -16,6 +16,7 @@
 */
 
 #include "searchlinestatus.h"
+#include "messagelist_debug.h"
 
 #include <KLocalizedString>
 #include <QAction>
@@ -25,10 +26,15 @@
 #include <KIconLoader>
 #include <QWidgetAction>
 #include <QPushButton>
+#include <QCompleter>
+#include <QContextMenuEvent>
+#include <QStringListModel>
 
+static const char qLineEditclearButtonActionNameC[] = "_q_qlineeditclearaction";
+#define MAX_COMPLETION_ITEMS 20
 using namespace MessageList::Core;
 SearchLineStatus::SearchLineStatus(QWidget *parent)
-    : PimCommon::LineEditWithCompleter(parent),
+    : QLineEdit(parent),
       mLocked(false),
       mHasFilter(false),
       mLockAction(nullptr),
@@ -36,10 +42,20 @@ SearchLineStatus::SearchLineStatus(QWidget *parent)
       mFilterMenu(nullptr),
       mContainsOutboundMessages(false)
 {
+    mCompleter = new QCompleter(this);
+    mCompleterListModel = new QStringListModel(this);
+    mCompleter->setModel(mCompleterListModel);
+    setCompleter(mCompleter);
+
     setClearButtonEnabled(true);
-    setClearButtonShown(false);
     initializeActions();
     createMenuSearch();
+    QAction *act = findChild<QAction *>(QLatin1String(qLineEditclearButtonActionNameC));
+    if (act) {
+        connect(act, &QAction::triggered, this, &SearchLineStatus::slotClear);
+    } else {
+        qCWarning(MESSAGELIST_LOG) << "Clear button name was changed ! Please verify qt code";
+    }
 }
 
 SearchLineStatus::~SearchLineStatus()
@@ -47,6 +63,11 @@ SearchLineStatus::~SearchLineStatus()
 
 }
 
+void SearchLineStatus::slotClear()
+{
+    Q_EMIT clearButtonClicked();
+}
+
 void SearchLineStatus::updateLockAction()
 {
     if (mLocked) {
@@ -149,7 +170,6 @@ void SearchLineStatus::clearFilterButtonClicked()
     clearFilterAction();
     clearFilterByAction();
     updateFilters();
-    slotSearchOptionChanged();
 }
 
 void SearchLineStatus::createMenuSearch()
@@ -294,13 +314,35 @@ QuickSearchLine::SearchOptions SearchLineStatus::searchOptions() const
     return searchOptions;
 }
 
-void SearchLineStatus::slotSearchOptionChanged()
-{
-    Q_EMIT searchOptionChanged();
-}
-
 void SearchLineStatus::slotFilterActionClicked(QAction *act)
 {
     Q_UNUSED(act);
-    slotSearchOptionChanged();
+    Q_EMIT searchOptionChanged();
+}
+
+void SearchLineStatus::addCompletionItem(const QString &str)
+{
+    mListCompetion.removeAll(str);
+    mListCompetion.prepend(str);
+    while (mListCompetion.size() > MAX_COMPLETION_ITEMS) {
+        mListCompetion.removeLast();
+    }
+    mCompleterListModel->setStringList(mListCompetion);
+}
+
+void SearchLineStatus::contextMenuEvent(QContextMenuEvent *e)
+{
+    QMenu *popup = QLineEdit::createStandardContextMenu();
+    if (popup) {
+        popup->addSeparator();
+        popup->addAction(QIcon::fromTheme(QStringLiteral("edit-clear-locationbar-rtl")), i18n("Clear History"), this, &SearchLineStatus::slotClearHistory);
+        popup->exec(e->globalPos());
+        delete popup;
+    }
+}
+
+void SearchLineStatus::slotClearHistory()
+{
+    mListCompetion.clear();
+    mCompleterListModel->setStringList(mListCompetion);
 }
