@@ -4,7 +4,7 @@
     This file is part of KMail, the KDE mail client.
     Copyright (c) 2003 Marc Mutz <mutz@kde.org>
 
-    Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+    Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
     KMail is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License, version 2, as
@@ -43,16 +43,17 @@ class MessageViewer::HeaderStylePrivate
 {
 public:
     HeaderStylePrivate()
-        : mStrategy(0),
-          mNodeHelper(0),
-          mSourceObject(0),
-          mPrinting(false),
-          mTopLevel(true),
-          mAllowAsync(false),
-          mReadOnlyMessage(false)
+        : mStrategy(nullptr)
+        , mNodeHelper(nullptr)
+        , mSourceObject(nullptr)
+        , mPrinting(false)
+        , mTopLevel(true)
+        , mAllowAsync(false)
+        , mReadOnlyMessage(false)
+        , mShowEmoticons(true)
     {
-
     }
+
     GrantleeTheme::Theme mTheme;
     QString mMessagePath;
     const HeaderStrategy *mStrategy;
@@ -65,6 +66,7 @@ public:
     bool mTopLevel;
     bool mAllowAsync;
     bool mReadOnlyMessage;
+    bool mShowEmoticons;
 };
 
 HeaderStyle::HeaderStyle()
@@ -202,3 +204,12 @@ void HeaderStyle::setReadOnlyMessage(bool readOnlyMessage)
     d->mReadOnlyMessage = readOnlyMessage;
 }
 
+bool HeaderStyle::showEmoticons() const
+{
+    return d->mShowEmoticons;
+}
+
+void HeaderStyle::setShowEmoticons(bool b)
+{
+    d->mShowEmoticons = b;
+}
