@@ -30,8 +30,9 @@
 
 using namespace MessageViewer;
 
-MailViewerSource::MailViewerSource(ViewerPrivate *viewer) :
-    MimeTreeParser::Interface::ObjectTreeSource(), mViewer(viewer)
+MailViewerSource::MailViewerSource(ViewerPrivate *viewer)
+    : MimeTreeParser::Interface::ObjectTreeSource()
+    , mViewer(viewer)
 {
 }
 
@@ -54,7 +55,8 @@ bool MailViewerSource::showSignatureDetails() const
     return mViewer->mShowSignatureDetails;
 }
 
-void MailViewerSource::setHtmlMode(MimeTreeParser::Util::HtmlMode mode, const QList<MimeTreeParser::Util::HtmlMode> &availableModes)
+void MailViewerSource::setHtmlMode(MimeTreeParser::Util::HtmlMode mode,
+                                   const QList<MimeTreeParser::Util::HtmlMode> &availableModes)
 {
     mViewer->mColorBar->setAvailableModes(availableModes);
     mViewer->mColorBar->setMode(mode);
@@ -63,15 +65,16 @@ void MailViewerSource::setHtmlMode(MimeTreeParser::Util::HtmlMode mode, const QL
 MimeTreeParser::Util::HtmlMode MailViewerSource::preferredMode() const
 {
     switch (mViewer->displayFormatMessageOverwrite()) {
-        case MessageViewer::Viewer::UseGlobalSetting:
-        case MessageViewer::Viewer::Unknown:
-            return mViewer->htmlMailGlobalSetting() ? MimeTreeParser::Util::Html : MimeTreeParser::Util::Normal;
-        case MessageViewer::Viewer::Html:
-            return MimeTreeParser::Util::MultipartHtml;
-        case MessageViewer::Viewer::Text:
-            return MimeTreeParser::Util::MultipartPlain;
-        case MessageViewer::Viewer::ICal:
-            return MimeTreeParser::Util::MultipartIcal;
+    case MessageViewer::Viewer::UseGlobalSetting:
+    case MessageViewer::Viewer::Unknown:
+        return mViewer->htmlMailGlobalSetting() ? MimeTreeParser::Util::Html : MimeTreeParser::Util
+               ::Normal;
+    case MessageViewer::Viewer::Html:
+        return MimeTreeParser::Util::MultipartHtml;
+    case MessageViewer::Viewer::Text:
+        return MimeTreeParser::Util::MultipartPlain;
+    case MessageViewer::Viewer::ICal:
+        return MimeTreeParser::Util::MultipartIcal;
     }
     Q_ASSERT(true);
     return MimeTreeParser::Util::Html;
@@ -92,11 +95,6 @@ QString MailViewerSource::createMessageHeader(KMime::Message *message)
     return mViewer->writeMsgHeader(message);
 }
 
-QObject *MailViewerSource::sourceObject()
-{
-    return mViewer;
-}
-
 const MimeTreeParser::AttachmentStrategy *MailViewerSource::attachmentStrategy()
 {
     return mViewer->attachmentStrategy();
@@ -114,7 +112,7 @@ bool MailViewerSource::autoImportKeys() const
 
 bool MailViewerSource::showEmoticons() const
 {
-    return MessageViewer::MessageViewerSettings::self()->showEmoticons();
+    return mViewer->showEmoticons();
 }
 
 bool MailViewerSource::showExpandQuotesMark() const
@@ -127,7 +125,15 @@ const MimeTreeParser::BodyPartFormatterBaseFactory *MailViewerSource::bodyPartFo
     return bodyPartFormatterBaseFactoryInstance();
 }
 
-MimeTreeParser::Interface::MessagePartRendererPtr MailViewerSource::messagePartTheme(MimeTreeParser::Interface::MessagePart::Ptr msgPart)
+bool MailViewerSource::isPrinting() const
 {
-    return  MimeTreeParser::Interface::MessagePartRenderer::Ptr(new DefaultRenderer(msgPart, mViewer->cssHelper()));
-}
\ No newline at end of file
+    return mViewer->mPrinting;
+}
+
+MimeTreeParser::Interface::MessagePartRendererPtr MailViewerSource::messagePartTheme(
+    MimeTreeParser::Interface::MessagePart::Ptr msgPart)
+{
+    return MimeTreeParser::Interface::MessagePartRenderer::Ptr(new DefaultRenderer(msgPart,
+                                                                                   mViewer->
+                                                                                   cssHelper()));
+}
