@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -27,7 +27,7 @@ class TestMailMBoxWebEngine : public QWidget
 {
     Q_OBJECT
 public:
-    explicit TestMailMBoxWebEngine(QWidget *parent = Q_NULLPTR);
+    explicit TestMailMBoxWebEngine(QWidget *parent = nullptr);
     ~TestMailMBoxWebEngine();
 private:
     KMime::Message::Ptr readAndParseMail(const QString &mailFile);
