@@ -4,7 +4,7 @@
     This file is part of KMail, the KDE mail client.
     Copyright (c) 2002 Ingo Kloecker <kloecker@kde.org>
     Copyright (c) 2003 Marc Mutz <mutz@kde.org>
-    Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+    Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
     KMail is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License, version 2, as
@@ -44,15 +44,17 @@
 using namespace MessageViewer;
 
 HtmlStatusBar::HtmlStatusBar(QWidget *parent)
-    : QLabel(parent),
-      mMode(MimeTreeParser::Util::Normal)
+    : QLabel(parent)
+    , mMode(MimeTreeParser::Util::Normal)
 {
     setAlignment(Qt::AlignHCenter | Qt::AlignTop);
     setAutoFillBackground(true);
     update();
 }
 
-HtmlStatusBar::~HtmlStatusBar() {}
+HtmlStatusBar::~HtmlStatusBar()
+{
+}
 
 MimeTreeParser::Util::HtmlMode HtmlStatusBar::mode() const
 {
@@ -232,4 +234,3 @@ QColor HtmlStatusBar::bgColor() const
         return Qt::white;
     }
 }
-
