@@ -25,9 +25,7 @@
 class QTabWidget;
 class QWebEnginePage;
 
-
-namespace MessageViewer
-{
+namespace MessageViewer {
 class FindBarSourceView;
 class MailSourceViewTextBrowserWidget;
 class MailSourceWebEngineViewer : public QDialog
