@@ -25,6 +25,7 @@
 #include <QVariant>
 class QWebEngineProfile;
 class QWebEngineDownloadItem;
+class QPrinter;
 namespace WebEngineViewer
 {
 class WebHitTest;
@@ -40,6 +41,8 @@ public:
     WebEngineViewer::WebHitTest *hitTestContent(const QPoint &pos);
 
     void saveHtml(QWebEngineDownloadItem *download);
+    bool execPrintPreviewPage(QPrinter *printer, int timeout);
+
 Q_SIGNALS:
     void urlClicked(const QUrl &url);
     void showConsoleMessage(const QString &message);
