@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -35,10 +35,10 @@ class WebEngineViewer::ZoomActionMenuPrivate
 public:
     ZoomActionMenuPrivate(KActionMenu *qq)
         : mZoomFactor(100),
-          mZoomInAction(Q_NULLPTR),
-          mZoomOutAction(Q_NULLPTR),
-          mZoomResetAction(Q_NULLPTR),
-          mActionCollection(Q_NULLPTR),
+          mZoomInAction(nullptr),
+          mZoomOutAction(nullptr),
+          mZoomResetAction(nullptr),
+          mActionCollection(nullptr),
           q(qq)
     {
 
